==> image-saas-metadata-0.1.516-sources.jar: com/xforceplus/ultraman/app/imagesaas/metadata/meta/FormMeta.java <==
package com.xforceplus.ultraman.app.imagesaas.metadata.meta;

/**
 * 表单元数据
 *
 * @author ultraman
 * @since 2023-10-26
 */

public class FormMeta {
    public interface ConfigDataMapping {
        static String code() {
            return "configDataMapping";
        }
        static String name() {
            return "识别规则";
        }
    }
    public interface ScanDetail {
        static String code() {
            return "scanDetail";
        }
        static String name() {
            return "影像详情";
        }
    }
    public interface TicketInvoice {
        static String code() {
            return "ticketInvoice";
        }
        static String name() {
            return "增值税发票";
        }
    }
    public interface OpenOrder {
        static String code() {
            return "openOrder";
        }
        static String name() {
            return "拆单";
        }
    }
    public interface TicketQuota {
        static String code() {
            return "ticketQuota";
        }
        static String name() {
            return "定额发票";
        }
    }
    public interface TicketMachine {
        static String code() {
            return "ticketMachine";
        }
        static String name() {
            return "通用机打发票";
        }
    }
    public interface TicketPlane {
        static String code() {
            return "ticketPlane";
        }
        static String name() {
            return "飞机票行程单";
        }
    }
    public interface TicketMany {
        static String code() {
            return "ticketMany";
        }
        static String name() {
            return "多票";
        }
    }
    public interface TicketSalesList {
        static String code() {
            return "ticketSalesList";
        }
        static String name() {
            return "销货清单";
        }
    }
    public interface TicketTrain {
        static String code() {
            return "ticketTrain";
        }
        static String name() {
            return "火车票";
        }
    }
    public interface TicketTaxi {
        static String code() {
            return "ticketTaxi";
        }
        static String name() {
            return "出租车";
        }
    }
    public interface TicketUsedCar {
        static String code() {
            return "ticketUsedCar";
        }
        static String name() {
            return "二手车发票";
        }
    }
    public interface TicketForm {
        static String code() {
            return "ticketForm";
        }
        static String name() {
            return "形式发票";
        }
    }
    public interface TicketBus {
        static String code() {
            return "ticketBus";
        }
        static String name() {
            return "公交车车票";
        }
    }
    public interface TicketToll {
        static String code() {
            return "ticketToll";
        }
        static String name() {
            return "过路费发票";
        }
    }
    public interface TicketAttachment {
        static String code() {
            return "ticketAttachment";
        }
        static String name() {
            return "附件";
        }
    }
    public interface TicketOther {
        static String code() {
            return "ticketOther";
        }
        static String name() {
            return "其他发票";
        }
    }
    public interface TicketVehicle {
        static String code() {
            return "ticketVehicle";
        }
        static String name() {
            return "机动车销售统一发票";
        }
    }
    public interface CompareTicketInvoice {
        static String code() {
            return "compareTicketInvoice";
        }
        static String name() {
            return "比对增值税发票";
        }
    }
    public interface CompareTicketTrain {
        static String code() {
            return "compareTicketTrain";
        }
        static String name() {
            return "比对火车票";
        }
    }
    public interface CompareTicketTaxi {
        static String code() {
            return "compareTicketTaxi";
        }
        static String name() {
            return "比对出租车";
        }
    }
    public interface CompareTicketQuota {
        static String code() {
            return "compareTicketQuota";
        }
        static String name() {
            return "比对定额发票";
        }
    }
    public interface CompareTicketPlane {
        static String code() {
            return "compareTicketPlane";
        }
        static String name() {
            return "比对飞机票";
        }
    }
    public interface CompareTicketBus {
        static String code() {
            return "compareTicketBus";
        }
        static String name() {
            return "比对公交车发票";
        }
    }
    public interface CompareTicketToll {
        static String code() {
            return "compareTicketToll";
        }
        static String name() {
            return "比对过路费发票";
        }
    }
    public interface CompareTicketUsedCar {
        static String code() {
            return "compareTicketUsedCar";
        }
        static String name() {
            return "比对二手车发票";
        }
    }
    public interface CompareTicketMachine {
        static String code() {
            return "compareTicketMachine";
        }
        static String name() {
            return "比对通用机打发票";
        }
    }
    public interface CompareTicketOther {
        static String code() {
            return "compareTicketOther";
        }
        static String name() {
            return "比对其他发票";
        }
    }
    public interface CompareTicketVehicle {
        static String code() {
            return "compareTicketVehicle";
        }
        static String name() {
            return "比对机动车销售统一发票";
        }
    }
    public interface CompareTicketAttachment {
        static String code() {
            return "compareTicketAttachment";
        }
        static String name() {
            return "比对附件";
        }
    }
    public interface TicketVirtual {
        static String code() {
            return "ticketVirtual";
        }
        static String name() {
            return "虚拟单证";
        }
    }
    public interface CompareTicketVirtual {
        static String code() {
            return "compareTicketVirtual";
        }
        static String name() {
            return "比对虚拟单证";
        }
    }
    public interface ScanTicketInvoice {
        static String code() {
            return "scanTicketInvoice";
        }
        static String name() {
            return "发票采集-增值税发票";
        }
    }
    public interface ScanTicketAttachment {
        static String code() {
            return "scanTicketAttachment";
        }
        static String name() {
            return "发票采集-附件";
        }
    }
    public interface TicketCustomsPayment {
        static String code() {
            return "ticketCustomsPayment";
        }
        static String name() {
            return "海关缴款书";
        }
    }
    public interface ScanDetailScreen {
        static String code() {
            return "scanDetailScreen";
        }
        static String name() {
            return "单据详情页筛选";
        }
    }
    public interface ScanUpload {
        static String code() {
            return "scanUpload";
        }
        static String name() {
            return "扫描上传";
        }
    }
    public interface TicketCustomsDeclaration {
        static String code() {
            return "ticketCustomsDeclaration";
        }
        static String name() {
            return " 海关报关单";
        }
    }
    public interface TicketFinance {
        static String code() {
            return "ticketFinance";
        }
        static String name() {
            return "财政票据";
        }
    }
    public interface TicketMedical {
        static String code() {
            return "ticketMedical";
        }
        static String name() {
            return "医疗票据";
        }
    }
    public interface CompareScanUpload {
        static String code() {
            return "compareScanUpload";
        }
        static String name() {
            return "稽核扫描上传";
        }
    }
    public interface ComparePassReason {
        static String code() {
            return "comparePassReason";
        }
        static String name() {
            return "收单稽核提交原因";
        }
    }
    public interface CompareTicketSalesList {
        static String code() {
            return "compareTicketSalesList";
        }
        static String name() {
            return "比对销货清单";
        }
    }
    public interface MarkRiskForm {
        static String code() {
            return "markRiskForm";
        }
        static String name() {
            return "风险标记表单";
        }
    }
    public interface ScanTodoPendingForm {
        static String code() {
            return "scanTodoPendingForm";
        }
        static String name() {
            return "扫描待办-挂起表单";
        }
    }
    public interface ScanTodoNoBackForm {
        static String code() {
            return "scanTodoNoBackForm";
        }
        static String name() {
            return "扫描待办-无需退回";
        }
    }
    public interface CompareReceiveNotifyFrom {
        static String code() {
            return "compareReceiveNotifyFrom";
        }
        static String name() {
            return "财务收单-单据-通知提单人";
        }
    }
}

==> image-saas-metadata-0.1.533-sources.jar: com/xforceplus/ultraman/app/imagesaas/metadata/meta/FormMeta.java <==
package com.xforceplus.ultraman.app.imagesaas.metadata.meta;

/**
 * 表单元数据
 *
 * @author ultraman
 * @since 2023-11-06
 */

public class FormMeta {
    public interface ConfigDataMapping {
        static String code() {
            return "configDataMapping";
        }
        static String name() {
            return "识别规则";
        }
    }
    public interface ScanDetail {
        static String code() {
            return "scanDetail";
        }
        static String name() {
            return "影像详情";
        }
    }
    public interface TicketInvoice {
        static String code() {
            return "ticketInvoice";
        }
        static String name() {
            return "增值税发票";
        }
    }
    public interface OpenOrder {
        static String code() {
            return "openOrder";
        }
        static String name() {
            return "拆单";
        }
    }
    public interface TicketQuota {
        static String code() {
            return "ticketQuota";
        }
        static String name() {
            return "定额发票";
        }
    }
    public interface TicketMachine {
        static String code() {
            return "ticketMachine";
        }
        static String name() {
            return "通用机打发票";
        }
    }
    public interface TicketPlane {
        static String code() {
            return "ticketPlane";
        }
        static String name() {
            return "飞机票行程单";
        }
    }
    public interface TicketMany {
        static String code() {
            return "ticketMany";
        }
        static String name() {
            return "多票";
        }
    }
    public interface TicketSalesList {
        static String code() {
            return "ticketSalesList";
        }
        static String name() {
            return "销货清单";
        }
    }
    public interface TicketTrain {
        static String code() {
            return "ticketTrain";
        }
        static String name() {
            return "火车票";
        }
    }
    public interface TicketTaxi {
        static String code() {
            return "ticketTaxi";
        }
        static String name() {
            return "出租车";
        }
    }
    public interface TicketUsedCar {
        static String code() {
            return "ticketUsedCar";
        }
        static String name() {
            return "二手车发票";
        }
    }
    public interface TicketForm {
        static String code() {
            return "ticketForm";
        }
        static String name() {
            return "形式发票";
        }
    }
    public interface TicketBus {
        static String code() {
            return "ticketBus";
        }
        static String name() {
            return "公交车车票";
        }
    }
    public interface TicketToll {
        static String code() {
            return "ticketToll";
        }
        static String name() {
            return "过路费发票";
        }
    }
    public interface TicketAttachment {
        static String code() {
            return "ticketAttachment";
        }
        static String name() {
            return "附件";
        }
    }
    public interface TicketOther {
        static String code() {
            return "ticketOther";
        }
        static String name() {
            return "其他发票";
        }
    }
    public interface TicketVehicle {
        static String code() {
            return "ticketVehicle";
        }
        static String name() {
            return "机动车销售统一发票";
        }
    }
    public interface CompareTicketInvoice {
        static String code() {
            return "compareTicketInvoice";
        }
        static String name() {
            return "比对增值税发票";
        }
    }
    public interface CompareTicketTrain {
        static String code() {
            return "compareTicketTrain";
        }
        static String name() {
            return "比对火车票";
        }
    }
    public interface CompareTicketTaxi {
        static String code() {
            return "compareTicketTaxi";
        }
        static String name() {
            return "比对出租车";
        }
    }
    public interface CompareTicketQuota {
        static String code() {
            return "compareTicketQuota";
        }
        static String name() {
            return "比对定额发票";
        }
    }
    public interface CompareTicketPlane {
        static String code() {
            return "compareTicketPlane";
        }
        static String name() {
            return "比对飞机票";
        }
    }
    public interface CompareTicketBus {
        static String code() {
            return "compareTicketBus";
        }
        static String name() {
            return "比对公交车发票";
        }
    }
    public interface CompareTicketToll {
        static String code() {
            return "compareTicketToll";
        }
        static String name() {
            return "比对过路费发票";
        }
    }
    public interface CompareTicketUsedCar {
        static String code() {
            return "compareTicketUsedCar";
        }
        static String name() {
            return "比对二手车发票";
        }
    }
    public interface CompareTicketMachine {
        static String code() {
            return "compareTicketMachine";
        }
        static String name() {
            return "比对通用机打发票";
        }
    }
    public interface CompareTicketOther {
        static String code() {
            return "compareTicketOther";
        }
        static String name() {
            return "比对其他发票";
        }
    }
    public interface CompareTicketVehicle {
        static String code() {
            return "compareTicketVehicle";
        }
        static String name() {
            return "比对机动车销售统一发票";
        }
    }
    public interface CompareTicketAttachment {
        static String code() {
            return "compareTicketAttachment";
        }
        static String name() {
            return "比对附件";
        }
    }
    public interface TicketVirtual {
        static String code() {
            return "ticketVirtual";
        }
        static String name() {
            return "虚拟单证";
        }
    }
    public interface CompareTicketVirtual {
        static String code() {
            return "compareTicketVirtual";
        }
        static String name() {
            return "比对虚拟单证";
        }
    }
    public interface ScanTicketInvoice {
        static String code() {
            return "scanTicketInvoice";
        }
        static String name() {
            return "发票采集增值税发票";
        }
    }
    public interface ScanTicketAttachment {
        static String code() {
            return "scanTicketAttachment";
        }
        static String name() {
            return "发票采集附件";
        }
    }
    public interface TicketCustomsPayment {
        static String code() {
            return "ticketCustomsPayment";
        }
        static String name() {
            return "海关缴款书";
        }
    }
    public interface ScanDetailScreen {
        static String code() {
            return "scanDetailScreen";
        }
        static String name() {
            return "单据详情页筛选";
        }
    }
    public interface ScanUpload {
        static String code() {
            return "scanUpload";
        }
        static String name() {
            return "扫描上传";
        }
    }
    public interface TicketCustomsDeclaration {
        static String code() {
            return "ticketCustomsDeclaration";
        }
        static String name() {
            return "海关报关单";
        }
    }
    public interface TicketFinance {
        static String code() {
            return "ticketFinance";
        }
        static String name() {
            return "财政票据";
        }
    }
    public interface TicketMedical {
        static String code() {
            return "ticketMedical";
        }
        static String name() {
            return "医疗票据";
        }
    }
    public interface CompareScanUpload {
        static String code() {
            return "compareScanUpload";
        }
        static String name() {
            return "稽核扫描上传";
        }
    }
    public interface ComparePassReason {
        static String code() {
            return "comparePassReason";
        }
        static String name() {
            return "收单稽核提交原因";
        }
    }
    public interface CompareTicketSalesList {
        static String code() {
            return "compareTicketSalesList";
        }
        static String name() {
            return "比对销货清单";
        }
    }
    public interface MarkRiskForm {
        static String code() {
            return "markRiskForm";
        }
        static String name() {
            return "风险标记表单";
        }
    }
    public interface ScanTodoPendingForm {
        static String code() {
            return "scanTodoPendingForm";
        }
        static String name() {
            return "扫描待办挂起表单";
        }
    }
    public interface ScanTodoNoBackForm {
        static String code() {
            return "scanTodoNoBackForm";
        }
        static String name() {
            return "扫描待办无需退回";
        }
    }
    public interface CompareReceiveNotifyFrom {
        static String code() {
            return "compareReceiveNotifyFrom";
        }
        static String name() {
            return "财务收单单据通知提单人";
        }
    }
}
